package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.DataCentersMapper;
import com.zyc.system.domain.DataCenters;
import com.zyc.system.service.IDataCentersService;

/**
 * 数据中心Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class DataCentersServiceImpl implements IDataCentersService 
{
    @Autowired
    private DataCentersMapper dataCentersMapper;

    /**
     * 查询数据中心
     * 
     * @param id 数据中心主键
     * @return 数据中心
     */
    @Override
    public DataCenters selectDataCentersById(Integer id)
    {
        return dataCentersMapper.selectDataCentersById(id);
    }

    /**
     * 查询数据中心列表
     * 
     * @param dataCenters 数据中心
     * @return 数据中心
     */
    @Override
    public List<DataCenters> selectDataCentersList(DataCenters dataCenters)
    {
        return dataCentersMapper.selectDataCentersList(dataCenters);
    }

    /**
     * 新增数据中心
     * 
     * @param dataCenters 数据中心
     * @return 结果
     */
    @Override
    public int insertDataCenters(DataCenters dataCenters)
    {
        return dataCentersMapper.insertDataCenters(dataCenters);
    }

    /**
     * 修改数据中心
     * 
     * @param dataCenters 数据中心
     * @return 结果
     */
    @Override
    public int updateDataCenters(DataCenters dataCenters)
    {
        return dataCentersMapper.updateDataCenters(dataCenters);
    }

    /**
     * 批量删除数据中心
     * 
     * @param ids 需要删除的数据中心主键
     * @return 结果
     */
    @Override
    public int deleteDataCentersByIds(Integer[] ids)
    {
        return dataCentersMapper.deleteDataCentersByIds(ids);
    }

    /**
     * 删除数据中心信息
     * 
     * @param id 数据中心主键
     * @return 结果
     */
    @Override
    public int deleteDataCentersById(Integer id)
    {
        return dataCentersMapper.deleteDataCentersById(id);
    }
}
