package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.DataCenters;
import com.zyc.system.service.IDataCentersService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 数据中心Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/DataCentersController")
public class DataCentersController extends BaseController
{
    @Autowired
    private IDataCentersService dataCentersService;

    /**
     * 查询数据中心列表
     */
    @PreAuthorize("@ss.hasPermi('system:centers:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataCenters dataCenters)
    {
        startPage();
        List<DataCenters> list = dataCentersService.selectDataCentersList(dataCenters);
        return getDataTable(list);
    }

    /**
     * 导出数据中心列表
     */
    @PreAuthorize("@ss.hasPermi('system:centers:export')")
    @Log(title = "数据中心", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataCenters dataCenters)
    {
        List<DataCenters> list = dataCentersService.selectDataCentersList(dataCenters);
        ExcelUtil<DataCenters> util = new ExcelUtil<DataCenters>(DataCenters.class);
        util.exportExcel(response, list, "数据中心数据");
    }

    /**
     * 获取数据中心详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:centers:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataCentersService.selectDataCentersById(id));
    }

    /**
     * 新增数据中心
     */
    @PreAuthorize("@ss.hasPermi('system:centers:add')")
    @Log(title = "数据中心", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataCenters dataCenters)
    {
        return toAjax(dataCentersService.insertDataCenters(dataCenters));
    }

    /**
     * 修改数据中心
     */
    @PreAuthorize("@ss.hasPermi('system:centers:edit')")
    @Log(title = "数据中心", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataCenters dataCenters)
    {
        return toAjax(dataCentersService.updateDataCenters(dataCenters));
    }

    /**
     * 删除数据中心
     */
    @PreAuthorize("@ss.hasPermi('system:centers:remove')")
    @Log(title = "数据中心", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataCentersService.deleteDataCentersByIds(ids));
    }
}
